@@ -67,11 +67,11 @@ pub type NSTDAudioSink = *mut Sink;
 /// Returns: `NSTDAudioHost host` - The default audio host.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_audio_host_default() -> NSTDAudioHost {
+pub unsafe extern "C" fn nstd_audio_host_default() -> NSTDAudioHost {
     Box::into_raw(Box::new(cpal::default_host()))
 }
 
-/// Generates `nstd_std_audio_host_default_*_device` functions.
+/// Generates `nstd_audio_host_default_*_device` functions.
 macro_rules! generate_default_device {
     ($name: ident, $method: ident) => {
         #[inline]
@@ -84,21 +84,15 @@ macro_rules! generate_default_device {
         }
     };
 }
-generate_default_device!(
-    nstd_std_audio_host_default_input_device,
-    default_input_device
-);
-generate_default_device!(
-    nstd_std_audio_host_default_output_device,
-    default_output_device
-);
+generate_default_device!(nstd_audio_host_default_input_device, default_input_device);
+generate_default_device!(nstd_audio_host_default_output_device, default_output_device);
 
 /// Frees a host's memory.
 /// Parameters:
 ///     `NSTDAudioHost *host` - Pointer to an audio host.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_audio_host_free(host: *mut NSTDAudioHost) {
+pub unsafe extern "C" fn nstd_audio_host_free(host: *mut NSTDAudioHost) {
     Box::from_raw(*host);
     *host = ptr::null_mut();
 }
@@ -108,7 +102,7 @@ pub unsafe extern "C" fn nstd_std_audio_host_free(host: *mut NSTDAudioHost) {
 ///     `NSTDAudioDevice device` - The device.
 /// Returns: `char *name` - The device name.
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_audio_device_name(device: NSTDAudioDevice) -> *mut c_char {
+pub unsafe extern "C" fn nstd_audio_device_name(device: NSTDAudioDevice) -> *mut c_char {
     match (*device).name() {
         Ok(name) => {
             let mut bytes = name.into_bytes();
@@ -124,12 +118,12 @@ pub unsafe extern "C" fn nstd_std_audio_device_name(device: NSTDAudioDevice) ->
 ///     `const char **name` - A device name.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_audio_device_free_name(name: *mut *mut c_char) {
+pub unsafe extern "C" fn nstd_audio_device_free_name(name: *mut *mut c_char) {
     drop(CString::from_raw(*name));
     *name = ptr::null_mut();
 }
 
-/// Generates `nstd_std_audio_device_default_*_config` functions.
+/// Generates `nstd_audio_device_default_*_config` functions.
 macro_rules! generate_device_default_config {
     ($name: ident, $method: ident) => {
         #[cfg_attr(feature = "clib", no_mangle)]
@@ -161,16 +155,13 @@ macro_rules! generate_device_default_config {
         }
     };
 }
+generate_device_default_config!(nstd_audio_device_default_input_config, default_input_config);
 generate_device_default_config!(
-    nstd_std_audio_device_default_input_config,
-    default_input_config
-);
-generate_device_default_config!(
-    nstd_std_audio_device_default_output_config,
+    nstd_audio_device_default_output_config,
     default_output_config
 );
 
-/// Generates `nstd_std_audio_device_build_*_stream` functions.
+/// Generates `nstd_audio_device_build_*_stream` functions.
 macro_rules! generate_device_build_stream {
     ($name: ident, $func: ident, $ptr_ty: ty) => {
         #[cfg_attr(feature = "clib", no_mangle)]
@@ -210,12 +201,12 @@ macro_rules! generate_device_build_stream {
     };
 }
 generate_device_build_stream!(
-    nstd_std_audio_device_build_input_stream,
+    nstd_audio_device_build_input_stream,
     build_input_stream,
     *const c_void
 );
 generate_device_build_stream!(
-    nstd_std_audio_device_build_output_stream,
+    nstd_audio_device_build_output_stream,
     build_output_stream,
     *mut c_void
 );
@@ -225,12 +216,12 @@ generate_device_build_stream!(
 ///     `NSTDAudioDevice *device` - Pointer to a device.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_audio_device_free(device: *mut NSTDAudioDevice) {
+pub unsafe extern "C" fn nstd_audio_device_free(device: *mut NSTDAudioDevice) {
     Box::from_raw(*device);
     *device = ptr::null_mut();
 }
 
-/// Generates `nstd_std_audio_stream_*` functions.
+/// Generates `nstd_audio_stream_*` functions.
 macro_rules! generate_stream_play_pause {
     ($name: ident, $method: ident) => {
         #[inline]
@@ -243,15 +234,15 @@ macro_rules! generate_stream_play_pause {
         }
     };
 }
-generate_stream_play_pause!(nstd_std_audio_stream_play, play);
-generate_stream_play_pause!(nstd_std_audio_stream_pause, pause);
+generate_stream_play_pause!(nstd_audio_stream_play, play);
+generate_stream_play_pause!(nstd_audio_stream_pause, pause);
 
 /// Frees an audio stream
 /// Parameters:
 ///     `NSTDAudioStream *stream` - Pointer to an audio stream.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_audio_stream_free(stream: *mut NSTDAudioStream) {
+pub unsafe extern "C" fn nstd_audio_stream_free(stream: *mut NSTDAudioStream) {
     Box::from_raw(*stream);
     *stream = ptr::null_mut();
 }
@@ -280,7 +271,7 @@ generate_build_stream!(build_output_stream, as_mut_ptr, *mut c_void, &mut [T]);
 /// Creates a play stream.
 /// Returns: `NSTDAudioPlayStream stream` - The new play stream.
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_audio_play_stream_new() -> NSTDAudioPlayStream {
+pub unsafe extern "C" fn nstd_audio_play_stream_new() -> NSTDAudioPlayStream {
     match OutputStream::try_default() {
         Ok((stream, handle)) => NSTDAudioPlayStream {
             stream: Box::into_raw(Box::new(stream)),
@@ -294,7 +285,7 @@ pub unsafe extern "C" fn nstd_std_audio_play_stream_new() -> NSTDAudioPlayStream
 /// Parameters:
 ///     `NSTDAudioPlayStream *stream` - The play stream.
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_audio_play_stream_free(stream: &mut NSTDAudioPlayStream) {
+pub unsafe extern "C" fn nstd_audio_play_stream_free(stream: &mut NSTDAudioPlayStream) {
     Box::from_raw(stream.stream);
     Box::from_raw(stream.handle);
     stream.stream = ptr::null_mut();
@@ -307,7 +298,7 @@ pub unsafe extern "C" fn nstd_std_audio_play_stream_free(stream: &mut NSTDAudioP
 /// Returns: `NSTDAudioSink sink` - The new audio sink.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_audio_sink_new(stream: &NSTDAudioPlayStream) -> NSTDAudioSink {
+pub unsafe extern "C" fn nstd_audio_sink_new(stream: &NSTDAudioPlayStream) -> NSTDAudioSink {
     match Sink::try_new(&*stream.handle) {
         Ok(sink) => Box::into_raw(Box::new(sink)),
         _ => ptr::null_mut(),
@@ -321,7 +312,7 @@ pub unsafe extern "C" fn nstd_std_audio_sink_new(stream: &NSTDAudioPlayStream) -
 ///     `const int should_loop` - Nonzero if the audio should be looped.
 /// Returns: `int errc` - Nonzero on error.
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_audio_sink_append_from_file(
+pub unsafe extern "C" fn nstd_audio_sink_append_from_file(
     sink: NSTDAudioSink,
     file: NSTDFile,
     should_loop: c_int,
@@ -350,7 +341,7 @@ pub unsafe extern "C" fn nstd_std_audio_sink_append_from_file(
 ///     `NSTDAudioSink sink` - The audio sink.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_audio_sink_play(sink: NSTDAudioSink) {
+pub unsafe extern "C" fn nstd_audio_sink_play(sink: NSTDAudioSink) {
     (*sink).play();
 }
 
@@ -359,7 +350,7 @@ pub unsafe extern "C" fn nstd_std_audio_sink_play(sink: NSTDAudioSink) {
 ///     `NSTDAudioSink sink` - The audio sink.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_audio_sink_pause(sink: NSTDAudioSink) {
+pub unsafe extern "C" fn nstd_audio_sink_pause(sink: NSTDAudioSink) {
     (*sink).pause();
 }
 
@@ -369,7 +360,7 @@ pub unsafe extern "C" fn nstd_std_audio_sink_pause(sink: NSTDAudioSink) {
 /// Returns: `int is_paused` - Whether or not the audio sink is paused.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_audio_sink_is_paused(sink: NSTDAudioSink) -> c_int {
+pub unsafe extern "C" fn nstd_audio_sink_is_paused(sink: NSTDAudioSink) -> c_int {
     (*sink).is_paused() as c_int
 }
 
@@ -378,7 +369,7 @@ pub unsafe extern "C" fn nstd_std_audio_sink_is_paused(sink: NSTDAudioSink) -> c
 ///     `NSTDAudioSink sink` - The audio sink.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_audio_sink_stop(sink: NSTDAudioSink) {
+pub unsafe extern "C" fn nstd_audio_sink_stop(sink: NSTDAudioSink) {
     (*sink).stop();
 }
 
@@ -387,7 +378,7 @@ pub unsafe extern "C" fn nstd_std_audio_sink_stop(sink: NSTDAudioSink) {
 ///     `NSTDAudioSink sink` - The audio sink.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_audio_sink_sleep_until_end(sink: NSTDAudioSink) {
+pub unsafe extern "C" fn nstd_audio_sink_sleep_until_end(sink: NSTDAudioSink) {
     (*sink).sleep_until_end();
 }
 
@@ -397,7 +388,7 @@ pub unsafe extern "C" fn nstd_std_audio_sink_sleep_until_end(sink: NSTDAudioSink
 /// Returns: `float volume` - The volume of the sink.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_audio_sink_get_volume(sink: NSTDAudioSink) -> c_float {
+pub unsafe extern "C" fn nstd_audio_sink_get_volume(sink: NSTDAudioSink) -> c_float {
     (*sink).volume()
 }
 
@@ -407,7 +398,7 @@ pub unsafe extern "C" fn nstd_std_audio_sink_get_volume(sink: NSTDAudioSink) ->
 ///     `const float volume` - The volume of the sink.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_audio_sink_set_volume(sink: NSTDAudioSink, volume: c_float) {
+pub unsafe extern "C" fn nstd_audio_sink_set_volume(sink: NSTDAudioSink, volume: c_float) {
     (*sink).set_volume(volume);
 }
 
@@ -417,7 +408,7 @@ pub unsafe extern "C" fn nstd_std_audio_sink_set_volume(sink: NSTDAudioSink, vol
 /// Returns: `NSTDUSize size` - The number of audio sources in an audio sink.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_audio_sink_length(sink: NSTDAudioSink) -> usize {
+pub unsafe extern "C" fn nstd_audio_sink_length(sink: NSTDAudioSink) -> usize {
     (*sink).len()
 }
 
@@ -426,7 +417,7 @@ pub unsafe extern "C" fn nstd_std_audio_sink_length(sink: NSTDAudioSink) -> usiz
 ///     `NSTDAudioSink *sink` - The audio sink.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_audio_sink_detach(sink: &mut NSTDAudioSink) {
+pub unsafe extern "C" fn nstd_audio_sink_detach(sink: &mut NSTDAudioSink) {
     let boxed_sink = Box::from_raw(*sink);
     boxed_sink.detach();
     *sink = ptr::null_mut();
@@ -437,7 +428,7 @@ pub unsafe extern "C" fn nstd_std_audio_sink_detach(sink: &mut NSTDAudioSink) {
 ///     `NSTDAudioSink *sink` - The audio sink.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_audio_sink_free(sink: &mut NSTDAudioSink) {
+pub unsafe extern "C" fn nstd_audio_sink_free(sink: &mut NSTDAudioSink) {
     Box::from_raw(*sink);
     *sink = ptr::null_mut();
 }
